@@ -10,6 +10,6 @@ test_that("tide_stations works", {
   expect_equal(tide_stations("Annapolis (US Naval Academy), Severn River, Maryland", rtide::harmonics), "Annapolis (US Naval Academy), Severn River, Maryland")
 
   expect_error(tide_stations("^Monterey$", rtide::harmonics), "no matching stations")
-  expect_error(tide_stations(1, rtide::harmonics), "stations must be of class 'character'")
+  expect_error(tide_stations(1, rtide::harmonics), "stations must be class character")
 })
 
